@@ -44,8 +44,18 @@ as.data.frame.CM_list <- function(x,
   
   regs_name <- paste0("REG_", regs[, "name"])
   
+  # get some info on the trial
+  trial_tech <- dat$packages$comps[[1]]$technologies[[1]]$tech_name
+  trial_pi <- dat$project$project_pi
+  trial_country <- dat$project$project_cnty
+  
   has_data <- length(dat[["data"]]) > 0
   
+  if (isFALSE(has_data)) {
+    message("Project ", project_name, " has no associated data. \n")
+    return(data.frame())
+  }
+  
   if (isTRUE(has_data)) {
     
     ncomp <- dat$project$project_numcom
@@ -274,6 +284,9 @@ as.data.frame.CM_list <- function(x,
   
   # add project name
   pack$project_name <- project_name
+  pack$technology <- trial_tech
+  pack$coordinator <- trial_pi
+  pack$country <- trial_country
   
   pack <- .set_long(pack, "package_id")
   
